# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg_stock_dz.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg_stock_dz.proto',
  package='MsgStockDz',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.message\200\001\001\210\001\001\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12msg_stock_dz.proto\x12\nMsgStockDz\x1a\x1fgoogle/protobuf/timestamp.proto\"2\n\x04Head\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0e\n\x06packid\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x16\n\x05Login\x12\r\n\x05token\x18\x01 \x01(\t\"&\n\x08\x45rrorMsg\x12\r\n\x05\x65rror\x18\x01 \x01(\r\x12\x0b\n\x03msg\x18\x02 \x01(\t\"&\n\x07KickMsg\x12\x0e\n\x06reason\x18\x01 \x01(\r\x12\x0b\n\x03msg\x18\x02 \x01(\t\"I\n\x03\x42id\x12\r\n\x05level\x18\x01 \x01(\r\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\r\x12\x14\n\x0c\x62roker_count\x18\x04 \x01(\r\"\xc4\x04\n\x05Quote\x12\x13\n\x0bupdate_flag\x18\x01 \x03(\x04\x12\x0e\n\x06market\x18\x02 \x01(\r\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12(\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\ttick_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tpack_type\x18\x06 \x01(\r\x12\x12\n\nquote_type\x18\x07 \x01(\r\x12\x11\n\ttick_flag\x18\x08 \x01(\r\x12\x11\n\ttick_type\x18\t \x01(\r\x12\x0b\n\x03now\x18\n \x01(\x01\x12\x0c\n\x04open\x18\x0b \x01(\x01\x12\x0c\n\x04high\x18\x0c \x01(\x01\x12\x0b\n\x03low\x18\r \x01(\x01\x12\x0b\n\x03\x61vg\x18\x0e \x01(\x01\x12\x0e\n\x06settle\x18\x0f \x01(\x01\x12\x0c\n\x04hold\x18\x10 \x01(\r\x12\x0e\n\x06volume\x18\x11 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x12 \x01(\x01\x12\x12\n\nlast_close\x18\x13 \x01(\x01\x12\x13\n\x0blast_settle\x18\x14 \x01(\x01\x12\x11\n\tlast_hold\x18\x15 \x01(\x01\x12\x17\n\x0f\x63ur_trade_count\x18\x16 \x01(\r\x12\x13\n\x0btrade_count\x18\x17 \x01(\r\x12\x12\n\ncur_volume\x18\x18 \x01(\r\x12\x12\n\nrise_limit\x18\x19 \x01(\x01\x12\x12\n\nfall_limit\x18\x1a \x01(\x01\x12\x1d\n\x04sell\x18\x1b \x03(\x0b\x32\x0f.MsgStockDz.Bid\x12\x1c\n\x03\x62uy\x18\x1c \x03(\x0b\x32\x0f.MsgStockDz.Bid\"0\n\x06\x42roker\x12\x14\n\x0c\x62roker_level\x18\x01 \x01(\r\x12\x10\n\x08\x62rokerid\x18\x02 \x03(\r\"\xa5\x01\n\nBrokerList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\r\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x04sell\x18\x04 \x03(\x0b\x32\x12.MsgStockDz.Broker\x12\x1f\n\x03\x62uy\x18\x05 \x03(\x0b\x32\x12.MsgStockDz.Broker\"l\n\x06SymExt\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0e\n\x06market\x18\x02 \x01(\r\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12(\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\"a\n\tMarketExt\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0e\n\x06market\x18\x02 \x01(\r\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"P\n\x08OtherExt\x12\x0c\n\x04type\x18\x01 \x01(\r\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"9\n\x0bUpdateEvent\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0e\n\x06market\x18\x02 \x01(\r\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t*\xef\x01\n\nUpdateFlag\x12\x07\n\x03now\x10\x00\x12\x08\n\x04open\x10\x01\x12\x08\n\x04high\x10\x02\x12\x07\n\x03low\x10\x03\x12\x07\n\x03\x61vg\x10\x04\x12\n\n\x06settle\x10\x05\x12\x08\n\x04hold\x10\x06\x12\n\n\x06volume\x10\x07\x12\n\n\x06\x61mount\x10\x08\x12\x0e\n\nlast_close\x10\t\x12\x0f\n\x0blast_settle\x10\n\x12\r\n\tlast_hold\x10\x0b\x12\x13\n\x0f\x63ur_trade_count\x10\x0c\x12\x0f\n\x0btrade_count\x10\r\x12\x0e\n\ncur_volume\x10\x0e\x12\x0e\n\nrise_limit\x10\x0f\x12\x0e\n\nfall_limit\x10\x10*\xba\x03\n\tReqTypeNo\x12\x12\n\x0eReqTypeNo_NULL\x10\x00\x12\x10\n\x0cHeart_TypeNo\x10\x01\x12\x16\n\x12Market_Push_TypeNo\x10\x02\x12\x17\n\x13\x42roker_Queue_TypeNo\x10\x03\x12!\n\x1dProduct_Extension_Data_TypeNo\x10\x04\x12 \n\x1cMarket_Expansion_Data_TypeNo\x10\x05\x12 \n\x1cOther_Data_Extensions_TypeNo\x10\x06\x12#\n\x1f\x44\x61ta_Update_Notification_TypeNo\x10\n\x12)\n%Product_Extension_Notification_TypeNo\x10\x0b\x12(\n$Market_Expansion_Notification_TypeNo\x10\x0c\x12-\n)Other_Data_Extensions_Notification_TypeNo\x10\r\x12\x1a\n\x16Login_Agreement_TypeNo\x10\x14\x12\x17\n\x13\x45rror_Packet_TypeNo\x10\x15\x12\x11\n\rKicked_TypeNo\x10\x16\x42.\n#com.kaisaglobal.proto.stock.message\x80\x01\x01\x88\x01\x01\x90\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_UPDATEFLAG = _descriptor.EnumDescriptor(
  name='UpdateFlag',
  full_name='MsgStockDz.UpdateFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='now', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='open', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='high', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='low', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='avg', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='settle', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hold', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='volume', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amount', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='last_close', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='last_settle', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='last_hold', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='cur_trade_count', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='trade_count', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='cur_volume', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='rise_limit', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='fall_limit', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1450,
  serialized_end=1689,
)
_sym_db.RegisterEnumDescriptor(_UPDATEFLAG)

UpdateFlag = enum_type_wrapper.EnumTypeWrapper(_UPDATEFLAG)
_REQTYPENO = _descriptor.EnumDescriptor(
  name='ReqTypeNo',
  full_name='MsgStockDz.ReqTypeNo',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ReqTypeNo_NULL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Heart_TypeNo', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Market_Push_TypeNo', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Broker_Queue_TypeNo', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Product_Extension_Data_TypeNo', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Market_Expansion_Data_TypeNo', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Other_Data_Extensions_TypeNo', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Data_Update_Notification_TypeNo', index=7, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Product_Extension_Notification_TypeNo', index=8, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Market_Expansion_Notification_TypeNo', index=9, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Other_Data_Extensions_Notification_TypeNo', index=10, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Login_Agreement_TypeNo', index=11, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Error_Packet_TypeNo', index=12, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Kicked_TypeNo', index=13, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1692,
  serialized_end=2134,
)
_sym_db.RegisterEnumDescriptor(_REQTYPENO)

ReqTypeNo = enum_type_wrapper.EnumTypeWrapper(_REQTYPENO)
now = 0
open = 1
high = 2
low = 3
avg = 4
settle = 5
hold = 6
volume = 7
amount = 8
last_close = 9
last_settle = 10
last_hold = 11
cur_trade_count = 12
trade_count = 13
cur_volume = 14
rise_limit = 15
fall_limit = 16
ReqTypeNo_NULL = 0
Heart_TypeNo = 1
Market_Push_TypeNo = 2
Broker_Queue_TypeNo = 3
Product_Extension_Data_TypeNo = 4
Market_Expansion_Data_TypeNo = 5
Other_Data_Extensions_TypeNo = 6
Data_Update_Notification_TypeNo = 10
Product_Extension_Notification_TypeNo = 11
Market_Expansion_Notification_TypeNo = 12
Other_Data_Extensions_Notification_TypeNo = 13
Login_Agreement_TypeNo = 20
Error_Packet_TypeNo = 21
Kicked_TypeNo = 22



_HEAD = _descriptor.Descriptor(
  name='Head',
  full_name='MsgStockDz.Head',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockDz.Head.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packid', full_name='MsgStockDz.Head.packid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='MsgStockDz.Head.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=117,
)


_LOGIN = _descriptor.Descriptor(
  name='Login',
  full_name='MsgStockDz.Login',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='MsgStockDz.Login.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=141,
)


_ERRORMSG = _descriptor.Descriptor(
  name='ErrorMsg',
  full_name='MsgStockDz.ErrorMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='MsgStockDz.ErrorMsg.error', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='MsgStockDz.ErrorMsg.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=181,
)


_KICKMSG = _descriptor.Descriptor(
  name='KickMsg',
  full_name='MsgStockDz.KickMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='MsgStockDz.KickMsg.reason', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='MsgStockDz.KickMsg.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=221,
)


_BID = _descriptor.Descriptor(
  name='Bid',
  full_name='MsgStockDz.Bid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='MsgStockDz.Bid.level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='MsgStockDz.Bid.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockDz.Bid.volume', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broker_count', full_name='MsgStockDz.Bid.broker_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=296,
)


_QUOTE = _descriptor.Descriptor(
  name='Quote',
  full_name='MsgStockDz.Quote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_flag', full_name='MsgStockDz.Quote.update_flag', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockDz.Quote.market', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockDz.Quote.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='MsgStockDz.Quote.time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_time', full_name='MsgStockDz.Quote.tick_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pack_type', full_name='MsgStockDz.Quote.pack_type', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_type', full_name='MsgStockDz.Quote.quote_type', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_flag', full_name='MsgStockDz.Quote.tick_flag', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_type', full_name='MsgStockDz.Quote.tick_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='MsgStockDz.Quote.now', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='MsgStockDz.Quote.open', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='MsgStockDz.Quote.high', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='MsgStockDz.Quote.low', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg', full_name='MsgStockDz.Quote.avg', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settle', full_name='MsgStockDz.Quote.settle', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hold', full_name='MsgStockDz.Quote.hold', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='MsgStockDz.Quote.volume', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='MsgStockDz.Quote.amount', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_close', full_name='MsgStockDz.Quote.last_close', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_settle', full_name='MsgStockDz.Quote.last_settle', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_hold', full_name='MsgStockDz.Quote.last_hold', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_trade_count', full_name='MsgStockDz.Quote.cur_trade_count', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_count', full_name='MsgStockDz.Quote.trade_count', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_volume', full_name='MsgStockDz.Quote.cur_volume', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rise_limit', full_name='MsgStockDz.Quote.rise_limit', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fall_limit', full_name='MsgStockDz.Quote.fall_limit', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell', full_name='MsgStockDz.Quote.sell', index=26,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy', full_name='MsgStockDz.Quote.buy', index=27,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=879,
)


_BROKER = _descriptor.Descriptor(
  name='Broker',
  full_name='MsgStockDz.Broker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_level', full_name='MsgStockDz.Broker.broker_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerid', full_name='MsgStockDz.Broker.brokerid', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=929,
)


_BROKERLIST = _descriptor.Descriptor(
  name='BrokerList',
  full_name='MsgStockDz.BrokerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockDz.BrokerList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockDz.BrokerList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockDz.BrokerList.type', index=2,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='MsgStockDz.BrokerList.time', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell', full_name='MsgStockDz.BrokerList.sell', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy', full_name='MsgStockDz.BrokerList.buy', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1097,
)


_SYMEXT = _descriptor.Descriptor(
  name='SymExt',
  full_name='MsgStockDz.SymExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockDz.SymExt.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockDz.SymExt.market', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockDz.SymExt.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='MsgStockDz.SymExt.time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='MsgStockDz.SymExt.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1207,
)


_MARKETEXT = _descriptor.Descriptor(
  name='MarketExt',
  full_name='MsgStockDz.MarketExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockDz.MarketExt.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockDz.MarketExt.market', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='MsgStockDz.MarketExt.time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='MsgStockDz.MarketExt.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1209,
  serialized_end=1306,
)


_OTHEREXT = _descriptor.Descriptor(
  name='OtherExt',
  full_name='MsgStockDz.OtherExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockDz.OtherExt.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='MsgStockDz.OtherExt.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='MsgStockDz.OtherExt.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1308,
  serialized_end=1388,
)


_UPDATEEVENT = _descriptor.Descriptor(
  name='UpdateEvent',
  full_name='MsgStockDz.UpdateEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='MsgStockDz.UpdateEvent.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='MsgStockDz.UpdateEvent.market', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='MsgStockDz.UpdateEvent.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1447,
)

_QUOTE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUOTE.fields_by_name['tick_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUOTE.fields_by_name['sell'].message_type = _BID
_QUOTE.fields_by_name['buy'].message_type = _BID
_BROKERLIST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BROKERLIST.fields_by_name['sell'].message_type = _BROKER
_BROKERLIST.fields_by_name['buy'].message_type = _BROKER
_SYMEXT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MARKETEXT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OTHEREXT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Head'] = _HEAD
DESCRIPTOR.message_types_by_name['Login'] = _LOGIN
DESCRIPTOR.message_types_by_name['ErrorMsg'] = _ERRORMSG
DESCRIPTOR.message_types_by_name['KickMsg'] = _KICKMSG
DESCRIPTOR.message_types_by_name['Bid'] = _BID
DESCRIPTOR.message_types_by_name['Quote'] = _QUOTE
DESCRIPTOR.message_types_by_name['Broker'] = _BROKER
DESCRIPTOR.message_types_by_name['BrokerList'] = _BROKERLIST
DESCRIPTOR.message_types_by_name['SymExt'] = _SYMEXT
DESCRIPTOR.message_types_by_name['MarketExt'] = _MARKETEXT
DESCRIPTOR.message_types_by_name['OtherExt'] = _OTHEREXT
DESCRIPTOR.message_types_by_name['UpdateEvent'] = _UPDATEEVENT
DESCRIPTOR.enum_types_by_name['UpdateFlag'] = _UPDATEFLAG
DESCRIPTOR.enum_types_by_name['ReqTypeNo'] = _REQTYPENO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Head = _reflection.GeneratedProtocolMessageType('Head', (_message.Message,), {
  'DESCRIPTOR' : _HEAD,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.Head)
  })
_sym_db.RegisterMessage(Head)

Login = _reflection.GeneratedProtocolMessageType('Login', (_message.Message,), {
  'DESCRIPTOR' : _LOGIN,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.Login)
  })
_sym_db.RegisterMessage(Login)

ErrorMsg = _reflection.GeneratedProtocolMessageType('ErrorMsg', (_message.Message,), {
  'DESCRIPTOR' : _ERRORMSG,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.ErrorMsg)
  })
_sym_db.RegisterMessage(ErrorMsg)

KickMsg = _reflection.GeneratedProtocolMessageType('KickMsg', (_message.Message,), {
  'DESCRIPTOR' : _KICKMSG,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.KickMsg)
  })
_sym_db.RegisterMessage(KickMsg)

Bid = _reflection.GeneratedProtocolMessageType('Bid', (_message.Message,), {
  'DESCRIPTOR' : _BID,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.Bid)
  })
_sym_db.RegisterMessage(Bid)

Quote = _reflection.GeneratedProtocolMessageType('Quote', (_message.Message,), {
  'DESCRIPTOR' : _QUOTE,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.Quote)
  })
_sym_db.RegisterMessage(Quote)

Broker = _reflection.GeneratedProtocolMessageType('Broker', (_message.Message,), {
  'DESCRIPTOR' : _BROKER,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.Broker)
  })
_sym_db.RegisterMessage(Broker)

BrokerList = _reflection.GeneratedProtocolMessageType('BrokerList', (_message.Message,), {
  'DESCRIPTOR' : _BROKERLIST,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.BrokerList)
  })
_sym_db.RegisterMessage(BrokerList)

SymExt = _reflection.GeneratedProtocolMessageType('SymExt', (_message.Message,), {
  'DESCRIPTOR' : _SYMEXT,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.SymExt)
  })
_sym_db.RegisterMessage(SymExt)

MarketExt = _reflection.GeneratedProtocolMessageType('MarketExt', (_message.Message,), {
  'DESCRIPTOR' : _MARKETEXT,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.MarketExt)
  })
_sym_db.RegisterMessage(MarketExt)

OtherExt = _reflection.GeneratedProtocolMessageType('OtherExt', (_message.Message,), {
  'DESCRIPTOR' : _OTHEREXT,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.OtherExt)
  })
_sym_db.RegisterMessage(OtherExt)

UpdateEvent = _reflection.GeneratedProtocolMessageType('UpdateEvent', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENT,
  '__module__' : 'msg_stock_dz_pb2'
  # @@protoc_insertion_point(class_scope:MsgStockDz.UpdateEvent)
  })
_sym_db.RegisterMessage(UpdateEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
